@@ -1,5 +1,5 @@
 "parcau" <-
-function(lmom) {
+function(lmom,...) {
    para <- vector(mode="numeric", length=2)
    names(para) <- c("xi","alpha")
    if(length(lmom$source) == 1 && lmom$source != "TLmoms" ) {
