@@ -1,5 +1,5 @@
 "pargev" <-
-function(lmom,checklmom=TRUE) {
+function(lmom,checklmom=TRUE,...) {
     para <- vector(mode="numeric", length=3)
     names(para) <- c("xi","alpha","kappa")
     #  METHOD: FOR  -0.8 LE TAU3 LT 1,  K IS APPROXIMATED BY RATIONAL
