@@ -1,5 +1,5 @@
 "pargno" <-
-function(lmom,checklmom=TRUE) {
+function(lmom,checklmom=TRUE,...) {
     para <- vector(mode="numeric", length=3)
     names(para) <- c("xi","alpha","kappa")
     "erf" <- function(x) 2 * pnorm(x * sqrt(2)) - 1
